@@ -223,9 +223,9 @@ def printall(incoming_message, response_actions, start_time):
     display_actions(response_actions)
     display_state()
 
-def print_sep(dur):
+def print_sep(sleep_seconds):
     print("-------------------------------")
-    time.sleep(dur)
+    time.sleep(sleep_seconds)
 
 if __name__ == '__main__':
     _tests()
